// ThisAddIn.cs
//
// PRESTO Starter Kit for Microsoft .NET 3.0
// 2007 Microsoft France
// Published under the CECILL-B Free Software license agreement.
// (http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.txt)
// 
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, 
// WHETHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED 
// WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE. 
// THE ENTIRE RISK OF USE OR RESULTS IN CONNECTION WITH THE USE OF THIS CODE 
// AND INFORMATION REMAINS WITH THE USER. 
//

using System;
using System.Windows.Forms;
using Microsoft.VisualStudio.Tools.Applications.Runtime;
using Word = Microsoft.Office.Interop.Word;
using Office = Microsoft.Office.Core;
using System.Diagnostics;

using Microsoft.Office.Tools;

namespace WordAddIn4Presto
{
    public partial class ThisAddIn
    {
        private void ThisAddIn_Startup(object sender, System.EventArgs e)
        {
            try
            {

                this.Application.WindowActivate +=
                    new Word.ApplicationEvents4_WindowActivateEventHandler(ThisApplication_WindowActivate);
                this.Application.WindowDeactivate +=
                    new Word.ApplicationEvents4_WindowDeactivateEventHandler(ThisApplication_WindowDeactivate);
                this.Application.DocumentOpen +=
                    new Word.ApplicationEvents4_DocumentOpenEventHandler(ThisApplication_DocumentOpen);
                this.Application.DocumentBeforeClose +=
                    new Word.ApplicationEvents4_DocumentBeforeCloseEventHandler(ThisApplication_DocumentBeforeClose);

            }
            catch (Exception ex)
            {
                Trace.Write(ex.Message.ToString());
            }
        }

        private void ThisAddIn_Shutdown(object sender, System.EventArgs e)
        {

        }


        public CustomTaskPane AddTaskPane(Word.Window parentWindow, string title)
        {
            try
            {
                foreach (CustomTaskPane existingCtp in this.CustomTaskPanes)
                {
                    if (existingCtp != null)
                    {
                        if ((existingCtp.Window == parentWindow) && (existingCtp.Title == title)) 
                        {
                            return existingCtp;
                        }
                    }
                }

                WordAddIn4Presto.UCPresto uc = new WordAddIn4Presto.UCPresto();
                CustomTaskPane ctp = this.CustomTaskPanes.Add(uc, title, parentWindow);
                ctp.DockPositionRestrict = Microsoft.Office.Core.MsoCTPDockPositionRestrict.msoCTPDockPositionRestrictNoHorizontal;
                ctp.Width = this.Application.ActiveWindow.Width / 2 - 140;

                ctp.Visible = false;
                ctp.VisibleChanged += new EventHandler(ctp_VisibleChanged);
                return ctp;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString(), "AddTaskPane");
                return null;
            }
        }


        public void RemoveTaskPane(Word.Window Wn)
        {
            try
            {
                System.Collections.Generic.List<CustomTaskPane> ctpRemoveList = new System.Collections.Generic.List<CustomTaskPane>();

                foreach (CustomTaskPane existingCtp in CustomTaskPanes)
                {
                    if (existingCtp.Window == Wn)
                        {
                            // Pour dclencher l'event de synchro du ribbon
                            existingCtp.Visible = false;
                            ctpRemoveList.Add(existingCtp);

                        }
                }
                foreach (CustomTaskPane existingCtp in ctpRemoveList)
                {
                    this.CustomTaskPanes.Remove(existingCtp);

                }

                for (int count = 0; count < ctpRemoveList.Count;count++ )
                {
                    ctpRemoveList.RemoveAt(count);
                }
  
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.ToString(), "RemoveTaskPane");
            }
        }

        void ctp_VisibleChanged(object sender, EventArgs e)
        {
            CustomTaskPane ctp = (CustomTaskPane)sender;

            string ctpTitle = ctp.Title.Replace(" ", "");

            this.ribbon.IsTaskPaneVisible = !this.ribbon.IsTaskPaneVisible;
            this.ribbon.InvalidateControl(ctpTitle);
        }

        #region Document Events

        void ThisApplication_DocumentBeforeClose(Word.Document Doc, ref bool Cancel)
        {
            Trace.Write("ThisApplication_DocumentBeforeClose");
        }

        void ThisApplication_DocumentOpen(Word.Document Doc)
        {
            Trace.Write("ThisApplication_DocumentOpen");

        }

        void ThisApplication_WindowDeactivate(Word.Document Doc, Word.Window Wn)
        {
            Trace.Write(Wn.Caption + " deactivate ThisApplication_WindowDeactivate");
        }

        void ThisApplication_WindowActivate(Word.Document Doc, Word.Window Wn)
        {
            Trace.Write(Wn.Caption + " activate ThisApplication_WindowActivate");
        }

        #endregion

        #region VSTO generated code

        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InternalStartup()
        {
            this.Startup += new System.EventHandler(ThisAddIn_Startup);
            this.Shutdown += new System.EventHandler(ThisAddIn_Shutdown);
        }

        #endregion
    }
}
